@@ -1,10 +1,8 @@
 #  Copyright 2021, Yahoo
 #  Licensed under the terms of the Apache 2.0 license. See the LICENSE file in the project root for terms
-import collections
 import json
 import random
 from types import SimpleNamespace
-from typing import Any
 
 from ...app_logger import AppLogger
 from ...testplan.attack import MachineTargetDefinition
@@ -13,69 +11,38 @@ from ...utils.dependency import DependencyUtils
 from ...utils.hooks import EventHook
 from .BaseExecutor import BaseExecutor
 
-(TaskQueueManager,) = DependencyUtils.import_from(
-    "ansible.executor.task_queue_manager", ("TaskQueueManager",), raise_error=False
-)
-(InventoryManager,) = DependencyUtils.import_from(
-    "ansible.inventory.manager", ("InventoryManager",), raise_error=False
-)
-(DataLoader,) = DependencyUtils.import_from(
-    "ansible.parsing.dataloader", ("DataLoader",), raise_error=False
-)
-(Play,) = DependencyUtils.import_from(
-    "ansible.playbook.play", ("Play",), raise_error=False
+(YChaosAnsibleResultCallback,) = DependencyUtils.import_from(
+    "ychaos.core.executor.common",
+    ("YChaosAnsibleResultCallback",),
+    raise_error=False,
+    warn=False,
 )
 
-CallbackBase: Any  # For mypy
-(CallbackBase,) = DependencyUtils.import_from(
-    "ansible.plugins.callback", ("CallbackBase",), raise_error=False
+(TaskQueueManager,) = DependencyUtils.import_from(
+    "ansible.executor.task_queue_manager",
+    ("TaskQueueManager",),
+    raise_error=False,
+    warn=False,
 )
+(InventoryManager,) = DependencyUtils.import_from(
+    "ansible.inventory.manager", ("InventoryManager",), raise_error=False, warn=False
+)
+(DataLoader,) = DependencyUtils.import_from(
+    "ansible.parsing.dataloader", ("DataLoader",), raise_error=False, warn=False
+)
+(Play,) = DependencyUtils.import_from(
+    "ansible.playbook.play", ("Play",), raise_error=False, warn=False
+)
+
 (VariableManager,) = DependencyUtils.import_from(
-    "ansible.vars.manager", ("VariableManager",), raise_error=False
+    "ansible.vars.manager", ("VariableManager",), raise_error=False, warn=False
 )
 
 (TaskResult,) = DependencyUtils.import_from(
-    "ansible.executor.task_result", ("TaskResult",), raise_error=False
+    "ansible.executor.task_result", ("TaskResult",), raise_error=False, warn=False
 )
 
 
-if CallbackBase:  # pragma: no cover
-
-    class YChaosAnsibleResultCallback(CallbackBase, EventHook):
-
-        __hook_events__ = collections.defaultdict(
-            EventHook.CallableType(TaskResult)
-        ).fromkeys(
-            (
-                "on_target_unreachable",
-                "on_target_failed",
-                "on_target_passed",
-            )
-        )
-
-        def __init__(self, *args, **kwargs):
-            super(YChaosAnsibleResultCallback, self).__init__()
-
-            EventHook.__init__(self)
-            self.hooks.update(kwargs.pop("hooks", dict()))
-
-            self.hosts_passed = dict()
-            self.hosts_unreachable = dict()
-            self.hosts_failed = dict()
-
-        def v2_runner_on_unreachable(self, result):
-            self.hosts_unreachable[result._host.get_name()] = result
-            self.execute_hooks("on_target_unreachable", result)
-
-        def v2_runner_on_ok(self, result):
-            self.hosts_passed[result._host.get_name()] = result
-            self.execute_hooks("on_target_passed", result)
-
-        def v2_runner_on_failed(self, result, ignore_errors=False):
-            self.hosts_failed[result._host.get_name()] = result
-            self.execute_hooks("on_target_failed", result)
-
-
 class MachineTargetExecutor(BaseExecutor):
     """
     The executor that executes the agent on a set of Virtual machines/Bare metals
